@@ -73,11 +73,7 @@ IncidenceCompletionPriority::IncidenceCompletionPriority(Ui::EventOrTodoDesktop
     connect(d->mUi->mCompletionSlider, qOverload<int>(&QSlider::valueChanged), this, [this](int val) {
         d->sliderValueChanged(val);
     });
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(d->mUi->mPriorityCombo, qOverload< int>(&QComboBox::currentIndexChanged), this, &IncidenceCompletionPriority::checkDirtyStatus);
-#else
-    connect(d->mUi->mPriorityCombo, qOverload<int, const QString &>(&QComboBox::currentIndexChanged), this, &IncidenceCompletionPriority::checkDirtyStatus);
-#endif
 }
 
 IncidenceCompletionPriority::~IncidenceCompletionPriority()
@@ -128,7 +124,11 @@ void IncidenceCompletionPriority::save(const KCalendarCore::Incidence::Ptr &inci
     if (d->mOrigPercentCompleted != -1) {
         todo->setPercentComplete(d->mOrigPercentCompleted);
     } else {
-        todo->setPercentComplete(d->mUi->mCompletionSlider->value());
+        const int pct = d->mUi->mCompletionSlider->value();
+        todo->setPercentComplete(pct);
+        if (pct >= 100) {
+            todo->setCompleted(QDateTime::currentDateTimeUtc());
+        }
     }
     todo->setPriority(d->mUi->mPriorityCombo->currentIndex());
 }
